@@ -9,6 +9,6 @@
 #endif
 /*-------------*/
 /* This string can be read by the Unix program "what" */
-#define VERINFO "@(#)Version: 2.8"
+#define VERINFO "@(#)Version: 2.10"
 /*-------------*/
-#endif H_CONFIG
+#endif //H_CONFIG
